@@ -2,6 +2,8 @@
  "refs"
  (lambda ()
    (LaTeX-add-bibitems
+    "monnahan2018"
+    "monnahan2019"
     "betancourt2014"
     "kristensen2016"
     "fournier2012"
@@ -11,5 +13,6 @@
     "neal2011"
     "betancourt2016"
     "betancourt2017intro"
-    "stan2017")))
+    "stan2017"))
+ :bibtex)
 
